@@ -15,13 +15,13 @@ change in the future.
 
 """
 
-import shutil
 import os
+import shutil
 
 from sphinx.errors import ConfigError
 
 from .utils import replace_py_ipynb
-from . import sphinx_compatibility
+from . import sphinx_compatibility, glr_path_static
 
 
 logger = sphinx_compatibility.getLogger('sphinx-gallery')
@@ -81,6 +81,7 @@ def gen_binder_rst(fpath, binder_conf, gallery_conf):
     ----------
     fpath: str
         The path to the `.py` file for which a Binder badge will be generated.
+
     binder_conf: dict or None
         If a dictionary it must have the following keys:
 
@@ -95,19 +96,37 @@ def gen_binder_rst(fpath, binder_conf, gallery_conf):
         'dependencies'
             A list of paths to dependency files that match the Binderspec.
 
+    gallery_conf : dict
+        Sphinx-Gallery configuration dictionary.
+
     Returns
     -------
     rst : str
         The reStructuredText for the Binder badge that links to this file.
     """
-    binder_conf = check_binder_conf(binder_conf)
     binder_url = gen_binder_url(fpath, binder_conf, gallery_conf)
-
+    # In theory we should be able to use glr_path_static for this, but Sphinx
+    # only allows paths to be relative to the build root. On Linux, absolute
+    # paths can be used and they work, but this does not seem to be
+    # documented behavior:
+    #     https://github.com/sphinx-doc/sphinx/issues/7772
+    # And in any case, it does not work on Windows, so here we copy the SVG to
+    # `images` for each gallery and link to it there. This will make
+    # a few copies, and there will be an extra in `_static` at the end of the
+    # build, but it at least works...
+    physical_path = os.path.join(
+        os.path.dirname(fpath), 'images', 'binder_badge_logo.svg')
+    os.makedirs(os.path.dirname(physical_path), exist_ok=True)
+    if not os.path.isfile(physical_path):
+        shutil.copyfile(
+            os.path.join(glr_path_static(), 'binder_badge_logo.svg'),
+            physical_path)
     rst = (
         "\n"
         "  .. container:: binder-badge\n\n"
-        "    .. image:: https://mybinder.org/badge_logo.svg\n"
+        "    .. image:: images/binder_badge_logo.svg\n"
         "      :target: {}\n"
+        "      :alt: Launch binder\n"
         "      :width: 150 px\n").format(binder_url)
     return rst
 
@@ -121,7 +140,7 @@ def copy_binder_files(app, exception):
         return
 
     gallery_conf = app.config.sphinx_gallery_conf
-    binder_conf = check_binder_conf(gallery_conf.get('binder'))
+    binder_conf = gallery_conf['binder']
 
     if not len(binder_conf) > 0:
         return
